---@brief
---
--- https://github.com/huderlem/poryscript-pls
---
--- Language server for poryscript (a high level scripting language for GBA-era Pokémon decompilation projects)

---@type vim.lsp.Config
return {
  cmd = { 'poryscript-pls' },
  filetypes = { 'pory' },
  root_markers = { '.git' },
}
